(
  /**
   * Help View Module for Trampoline 
   * @memberof Trampolone
   * @namespace help
   * 
   * @event HELP_OPEN
   * @event HELP_CLOSE
   */
  function(Trampoline){
  Trampoline.help = (function (){
    var _didInit = false,
		_didBuild = false,
        _trampolineContainer,
        _helpContainer,
        _helpContentContainer,
        _panelActive,
        _log = Trampoline._log,    
        _config = null,
        tapEvent = Trampoline.util.tapEvent,

        //Events
        HELP_CLOSE  = new Event('HELP_CLOSE'),
        HELP_OPEN   = new Event('HELP_OPEN'),

        /**
         * Initialize 
         *Section
         * Adds event triggers to the Help Container
         * @memberof Trampoline.help
         */
        init = function( config ){
          _config = config;
          _log('Initiating Help Section...');
          _trampolineContainer = Trampoline.container || document.getElementById('trampoline');
          _helpContainer    = _trampolineContainer.querySelector('section.help');
          _addHelpSection();

          _helpContainer.addEventListener('touchmove', Trampoline.util.preventDefaultThis);
          _didInit = true;
        },
        /**
         * Toggles Help Bar DOM view with animation
         * @memberof Trampoline.help
         */
        toggleView = function(){
          if (!!_panelActive){
            _close();
          }else{
            _open();
          }
        },
        _open = function (){
          _panelActive = true;
          _helpContainer.classList.add('active');
          if (!Trampoline.util.isConnected){
            _helpContainer.classList.add('offline');
          }else if( _helpContainer.classList.contains('offline') ){
            _helpContainer.classList.remove('offline');
          }
          Trampoline.analytics.event('Help', 'open');
          Trampoline.events.dispatchEvent(HELP_OPEN);
        },
        _close = function (){
          _panelActive = false;
          _helpContainer.classList.remove('active');
          Trampoline.events.dispatchEvent(HELP_CLOSE);
        },
        _addHelpSection = function(){
          Trampoline.util.fetch('help.html', function(data) {
            var helpContainer = _trampolineContainer.querySelector('section.help');
            helpContainer.innerHTML = data;
            Trampoline.util.makeSticky(helpContainer.querySelector('nav'), helpContainer.querySelector('.help-wrapper'));
            
            // add swipe down to close
            var _scrollParent = _trampolineContainer.querySelector('section.help .content-wrapper');
            Trampoline.util.addSwipePull(_helpContainer, {dY: -0.10, state: 'back', scrollParent: _scrollParent});

            _trampolineContainer.classList.add('has-help');
            _trampolineContainer.querySelector('.help nav .close').addEventListener(tapEvent, function(e){
              e.preventDefault();
              Trampoline.util.toggleAnimation(e.target, 'tapped', 'tap-exit');
              Trampoline.state.back();
            });
          });
        },
        /**
         * Removes Help Area from DOM
         */
        remove = function (){
          if (!_helpContainer){
            _helpContainer = document.getElementById('trampoline').querySelector('section.help');
          }
          _helpContainer.parentElement.removeChild(_helpContainer);
        };

    return {
      init              : init,
      toggleView        : toggleView,
      remove            : remove
    };
  })();
            
  return Trampoline;
  
}(Trampoline || {}));
